#
# spec file for package opencensus-cpp
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_install_dir /usr/src/%{name}

Name:           opencensus-cpp
Version:        0.4.0+git.20190924
Release:        1.11
Summary:        A stats collection and distributed tracing framework
License:        Apache-2.0
Url:            https://github.com/census-instrumentation/opencensus-cpp
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildArch:      noarch

%description
OpenCensus is a toolkit for collecting application performance and behavior
data. It currently includes an API for tracing and stats.

%package source
Summary:        Source code of opencensus-cpp

%description source
OpenCensus is a toolkit for collecting application performance and behavior
data. It currently includes an API for tracing and stats.

This package provides source code of opencensus-cpp.

%prep
%autosetup -p1
cat <<EOF >> WORKSPACE
OPENSSL_BUILD_CONTENT = """
cc_library(
    name = "openssl-lib",
    hdrs = glob([
        "thirdparty_build/include/openssl",
        "thirdparty_build/include/ssl",
    ]),
    copts = [
        "-I/usr/include/openssl",
        "-I/usr/include/ssl",
    ],
    linkopts = ["-lssl", "-lcrypto"],
    visibility = ["//visibility:public"],
    linkstatic = False,
)
"""

new_local_repository(
    name = "openssl",
    path = "%{_libdir}",
    build_file_content = OPENSSL_BUILD_CONTENT,
)
EOF

sed -i -e "s|#define OPENCENSUS_VERSION .*|#define OPENCENSUS_VERSION \"%{version}\"|" \
    opencensus/common/version.h

sed -i \
    -e "/load_civetweb/d" \
    -e "s|go_register_toolchains()|go_register_toolchains(\"host\")|g" \
    WORKSPACE

sed -i \
    -e "s|@com_github_jupp0r_prometheus_cpp//core|@com_github_jupp0r_prometheus_cpp//:core|" \
    -e "s|com_github_jupp0r_prometheus_cpp//pull|com_github_jupp0r_prometheus_cpp//:pull|" \
    opencensus/exporters/stats/prometheus/BUILD

%build

%install
mkdir -p %{buildroot}%{src_install_dir}
cp -r * %{buildroot}%{src_install_dir}
%fdupes %{buildroot}%{src_install_dir}

%files source
%license LICENSE
%doc README.md
%{src_install_dir}

%changelog
* Mon Jan 20 2020 Michał Rostecki <mrostecki@opensuse.org>
- Remove patches which are not needed anymore:
  * 0001-bazel-Remove-and-add-deps-in-WORKSPACE.patch
  * 0002-Stackdriver-stats-Return-false-in-matcher-when-type-.patch
* Fri Jan 17 2020 Michał Rostecki <mrostecki@opensuse.org>
- Remove all subpackages except source. Envoy-proxy needs
  opencensus-cpp source tree to build and nothing else consomes
  opencensus-cpp as a shared library.
* Thu Jan  9 2020 mrostecki@opensuse.org
- Update to version 0.4.0+git.20190924:
  * Add OcAgentOptions override for service_name.
  * Fix ocagent trace exporter.
  * Stackdriver stats: resource must uniquely identify a timeseries.
  * Make default Stackdriver exporter deadlines match opencensus-java.
  * Fix switch fallthrough warnings.
  * Add comments about why opencensus_task is added.
  * Stackdriver stats: improve handling of builtin metrics.
  * Simplify WORKSPACE file.
  * Add default cases for view data switch.
  * Fix BUILD nit: tag_key_test depends on absl/hash.
  * Remove grpc_java, it's no longer needed by opencensus-proto.
  * Get rules_apple and apple_support via grpc_deps.
  * Rename io_opencensus_proto to opencensus_proto to match Envoy.
  * Build fix.
  * Make B3 parser more readable.
  * Update benchmarking docs.
  * Nit: use the constant.
  * SpanImpl::name() has to grab a lock and copy the name.
  * Switch from custom hash_mix to absl::Hash.
  * Build fix: grpc needs build_bazel_apple_support.
  * OcAgent: report errors, add to example, add docs.
  * Add OcAgent Trace Exporter.
  * Use StubInterface instead of Stub, for mocks.
  * Add B3 propagation helpers.
  * Build fix: provide a @bazel_version repository.
  * Stackdriver stats exporter: make opencensus_task optional.
  * Add com_google_googleapis to pin_deps.
* Mon Jan  6 2020 Michał Rostecki <mrostecki@opensuse.org>
- Add bazel-rules-swift-souce as dependency.
* Fri Nov 29 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Sort find output to make build reproducible (boo#1041090)
* Wed Nov 13 2019 Michał Rostecki <mrostecki@opensuse.org>
- Exclude arch to %%ix86
* Mon Nov 11 2019 Michał Rostecki <mrostecki@opensuse.org>
- Define OpenSSL Bazel repository
* Mon Nov 11 2019 Michał Rostecki <mrostecki@opensuse.org>
- Add patch which fixes the rpmlint issue about random values
  returned:
  * 0002-Stackdriver-stats-Return-false-in-matcher-when-type-.patch
* Mon Nov  4 2019 Michał Rostecki <mrostecki@opensuse.org>
- Initial release
